@@ -143,10 +143,12 @@ module TZInfo
       timezone 'America/Kentucky/Louisville'
       timezone 'America/Kentucky/Monticello'
       linked_timezone 'America/Knox_IN'
+      linked_timezone 'America/Kralendijk'
       timezone 'America/La_Paz'
       timezone 'America/Lima'
       timezone 'America/Los_Angeles'
       linked_timezone 'America/Louisville'
+      linked_timezone 'America/Lower_Princes'
       timezone 'America/Maceio'
       timezone 'America/Managua'
       timezone 'America/Manaus'
